import boto3
from botocore.exceptions import ClientError


def get_secret(secret_name, region_name):
    # Create a Secrets Manager client
    session = boto3.session.Session()
    client = session.client(service_name="secretsmanager", region_name=region_name)

    try:
        get_secret_value_response = client.get_secret_value(SecretId=secret_name)
    except ClientError as error:
        raise error

    # Decrypts secret using the associated KMS key.
    secret = get_secret_value_response["SecretString"]
    return secret


def check_if_ts_table_exists(database_name, table_name):
    try:
        ts_client = boto3.client("timestream-write")
        ts_client.describe_table(DatabaseName=database_name, TableName=table_name)
        return True
    except ts_client.exceptions.ResourceNotFoundException:
        return False
    except Exception as err:
        print("Describe table failed: ", err)
        return False


# Used it initially to find if table exists, but substituted
# with describe api since its easier and cleaner
# Leaving the code in utils if we need it in the future
def traverse_timestream_table(database_name, table_name):
    try:
        ts_client = boto3.client("timestream-write")
        ts_tables = ts_client.list_tables(DatabaseName=database_name, MaxResults=5)

        table_exists = check_ts_tables_results(ts_tables, table_name)
        if table_exists == True:
            return table_exists
        else:
            return continue_ts_traversal(
                ts_client, ts_tables, database_name, table_name
            )
    except Exception as err:
        print("List tables failed: ", err)


def check_ts_tables_results(ts_tables, table_name):
    for table in ts_tables["Tables"]:
        if table["TableName"] == table_name:
            return True


def continue_ts_traversal(ts_client, ts_tables, database_name, table_name):
    next_token = ts_tables.get("NextToken", None)
    while next_token:
        ts_tables = ts_client.list_tables(
            DatabaseName=database_name, NextToken=next_token, MaxResults=5
        )

        table_exists = check_ts_tables_results(ts_tables, table_name)
        if table_exists == True:
            return table_exists
        else:
            next_token = ts_tables.get("NextToken", None)
